pub enum ActiveLevel {
High,
Low,
}Expand description
Electrical level that represents a pressed button.
Variants
High
The button is pressed when the input pin reads high.
Low
The button is pressed when the input pin reads low.